Please see [https://docs.mlcommons.org/cm4mlops/scripts/Compiler-automation/install-onednn-from-src](https://docs.mlcommons.org/cm4mlops/scripts/Compiler-automation/install-onednn-from-src) for the documentation of this CM script.
